summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--chrome/browser/autocomplete/autocomplete_edit_unittest.cc6
-rw-r--r--chrome/browser/ui/app_modal_dialogs/app_modal_dialog.cc2
-rw-r--r--chrome/browser/ui/bookmarks/bookmark_tab_helper.cc4
-rw-r--r--chrome/browser/ui/browser.cc4
-rw-r--r--chrome/browser/ui/cocoa/applescript/tab_applescript.mm45
-rw-r--r--chrome/browser/ui/cocoa/bookmarks/bookmark_bar_controller.mm2
-rw-r--r--chrome/browser/ui/cocoa/browser_window_cocoa.mm4
-rw-r--r--chrome/browser/ui/cocoa/browser_window_controller.h8
-rw-r--r--chrome/browser/ui/cocoa/browser_window_controller.mm4
-rw-r--r--chrome/browser/ui/cocoa/browser_window_controller_private.mm2
-rw-r--r--chrome/browser/ui/cocoa/constrained_window_mac.mm4
-rw-r--r--chrome/browser/ui/cocoa/content_settings/collected_cookies_mac.mm1
-rw-r--r--chrome/browser/ui/cocoa/dev_tools_controller.mm2
-rw-r--r--chrome/browser/ui/cocoa/extensions/browser_actions_controller.mm1
-rw-r--r--chrome/browser/ui/cocoa/extensions/extension_action_context_menu.mm2
-rw-r--r--chrome/browser/ui/cocoa/find_bar/find_bar_cocoa_controller.mm8
-rw-r--r--chrome/browser/ui/cocoa/html_dialog_window_controller.mm8
-rw-r--r--chrome/browser/ui/cocoa/hung_renderer_controller.mm6
-rw-r--r--chrome/browser/ui/cocoa/infobars/extension_infobar_controller.mm2
-rw-r--r--chrome/browser/ui/cocoa/location_bar/content_setting_decoration.mm2
-rw-r--r--chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.h8
-rw-r--r--chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.mm6
-rw-r--r--chrome/browser/ui/cocoa/location_bar/location_icon_decoration.mm2
-rw-r--r--chrome/browser/ui/cocoa/location_bar/page_action_decoration.mm2
-rw-r--r--chrome/browser/ui/cocoa/notifications/balloon_controller.mm2
-rw-r--r--chrome/browser/ui/cocoa/omnibox/omnibox_view_mac.h14
-rw-r--r--chrome/browser/ui/cocoa/omnibox/omnibox_view_mac.mm15
-rw-r--r--chrome/browser/ui/cocoa/ssl_client_certificate_selector.mm1
-rw-r--r--chrome/browser/ui/cocoa/tab_contents/previewable_contents_controller.h8
-rw-r--r--chrome/browser/ui/cocoa/tab_contents/previewable_contents_controller.mm6
-rw-r--r--chrome/browser/ui/cocoa/tab_contents/tab_contents_controller.mm3
-rw-r--r--chrome/browser/ui/cocoa/toolbar/toolbar_controller.h7
-rw-r--r--chrome/browser/ui/cocoa/toolbar/toolbar_controller.mm5
-rw-r--r--chrome/browser/ui/cocoa/web_intent_picker_cocoa.mm1
-rw-r--r--chrome/browser/ui/content_settings/content_setting_bubble_model.cc13
-rw-r--r--chrome/browser/ui/gtk/location_bar_view_gtk.cc4
-rw-r--r--chrome/browser/ui/gtk/location_bar_view_gtk.h5
-rw-r--r--chrome/browser/ui/gtk/omnibox/omnibox_view_gtk.cc4
-rw-r--r--chrome/browser/ui/gtk/omnibox/omnibox_view_gtk.h18
-rw-r--r--chrome/browser/ui/omnibox/location_bar.h9
-rw-r--r--chrome/browser/ui/omnibox/omnibox_view.h11
-rw-r--r--chrome/browser/ui/views/location_bar/location_bar_view.cc4
-rw-r--r--chrome/browser/ui/views/location_bar/location_bar_view.h5
-rw-r--r--chrome/browser/ui/views/omnibox/omnibox_view_views.cc6
-rw-r--r--chrome/browser/ui/views/omnibox/omnibox_view_views.h10
-rw-r--r--chrome/browser/ui/views/omnibox/omnibox_view_win.cc5
-rw-r--r--chrome/browser/ui/views/omnibox/omnibox_view_win.h17
-rw-r--r--chrome/browser/ui/views/toolbar_view.cc3
-rw-r--r--chrome/browser/ui/views/toolbar_view.h2
-rw-r--r--chrome/test/base/test_location_bar.h2
50 files changed, 149 insertions, 166 deletions
diff --git a/chrome/browser/autocomplete/autocomplete_edit_unittest.cc b/chrome/browser/autocomplete/autocomplete_edit_unittest.cc
index a9a75fb..9771f94 100644
--- a/chrome/browser/autocomplete/autocomplete_edit_unittest.cc
+++ b/chrome/browser/autocomplete/autocomplete_edit_unittest.cc
@@ -10,6 +10,8 @@
#include "testing/gtest/include/gtest/gtest.h"
#include "third_party/skia/include/core/SkBitmap.h"
+using content::WebContents;
+
namespace {
class TestingOmniboxView : public OmniboxView {
@@ -18,8 +20,8 @@ class TestingOmniboxView : public OmniboxView {
virtual AutocompleteEditModel* model() OVERRIDE { return NULL; }
virtual const AutocompleteEditModel* model() const OVERRIDE { return NULL; }
- virtual void SaveStateToTab(TabContents* tab) OVERRIDE {}
- virtual void Update(const TabContents* tab_for_state_restoring) OVERRIDE {}
+ virtual void SaveStateToTab(WebContents* tab) OVERRIDE {}
+ virtual void Update(const WebContents* tab_for_state_restoring) OVERRIDE {}
virtual void OpenMatch(const AutocompleteMatch& match,
WindowOpenDisposition disposition,
const GURL& alternate_nav_url,
diff --git a/chrome/browser/ui/app_modal_dialogs/app_modal_dialog.cc b/chrome/browser/ui/app_modal_dialogs/app_modal_dialog.cc
index e77f88d..e951926 100644
--- a/chrome/browser/ui/app_modal_dialogs/app_modal_dialog.cc
+++ b/chrome/browser/ui/app_modal_dialogs/app_modal_dialog.cc
@@ -4,11 +4,11 @@
#include "chrome/browser/ui/app_modal_dialogs/app_modal_dialog.h"
+#include "base/logging.h"
#include "chrome/browser/ui/app_modal_dialogs/app_modal_dialog_queue.h"
#include "chrome/browser/ui/app_modal_dialogs/native_app_modal_dialog.h"
#include "chrome/common/chrome_notification_types.h"
#include "content/browser/javascript_dialogs.h"
-#include "content/browser/tab_contents/tab_contents.h"
#include "content/public/browser/notification_service.h"
AppModalDialog::AppModalDialog(content::DialogDelegate* delegate,
diff --git a/chrome/browser/ui/bookmarks/bookmark_tab_helper.cc b/chrome/browser/ui/bookmarks/bookmark_tab_helper.cc
index 7f2728e..e4b5e7a 100644
--- a/chrome/browser/ui/bookmarks/bookmark_tab_helper.cc
+++ b/chrome/browser/ui/bookmarks/bookmark_tab_helper.cc
@@ -11,9 +11,9 @@
#include "chrome/browser/ui/tab_contents/tab_contents_wrapper.h"
#include "chrome/browser/ui/webui/chrome_web_ui.h"
#include "chrome/common/chrome_notification_types.h"
-#include "content/browser/tab_contents/tab_contents.h"
#include "content/public/browser/navigation_controller.h"
#include "content/public/browser/notification_service.h"
+#include "content/public/browser/web_contents.h"
namespace {
@@ -24,7 +24,7 @@ bool CanShowBookmarkBar(WebUI* ui) {
} // namespace
BookmarkTabHelper::BookmarkTabHelper(TabContentsWrapper* tab_contents)
- : content::WebContentsObserver(tab_contents->tab_contents()),
+ : content::WebContentsObserver(tab_contents->web_contents()),
is_starred_(false),
tab_contents_wrapper_(tab_contents),
delegate_(NULL),
diff --git a/chrome/browser/ui/browser.cc b/chrome/browser/ui/browser.cc
index 04c0634..e2484d1 100644
--- a/chrome/browser/ui/browser.cc
+++ b/chrome/browser/ui/browser.cc
@@ -3293,7 +3293,7 @@ void Browser::TabDeactivated(TabContentsWrapper* contents) {
// Save what the user's currently typing, so it can be restored when we
// switch back to this tab.
- window_->GetLocationBar()->SaveStateToContents(contents->tab_contents());
+ window_->GetLocationBar()->SaveStateToContents(contents->web_contents());
}
void Browser::ActiveTabChanged(TabContentsWrapper* old_contents,
@@ -5095,7 +5095,7 @@ void Browser::TabDetachedAtImpl(TabContentsWrapper* contents, int index,
if (contents == GetSelectedTabContentsWrapper()) {
LocationBar* location_bar = window()->GetLocationBar();
if (location_bar)
- location_bar->SaveStateToContents(contents->tab_contents());
+ location_bar->SaveStateToContents(contents->web_contents());
}
if (!tab_handler_->GetTabStripModel()->closing_all())
diff --git a/chrome/browser/ui/cocoa/applescript/tab_applescript.mm b/chrome/browser/ui/cocoa/applescript/tab_applescript.mm
index 1f1ca8f..9b64abc 100644
--- a/chrome/browser/ui/cocoa/applescript/tab_applescript.mm
+++ b/chrome/browser/ui/cocoa/applescript/tab_applescript.mm
@@ -20,9 +20,9 @@
#include "chrome/common/url_constants.h"
#include "content/browser/download/save_package.h"
#include "content/browser/renderer_host/render_view_host.h"
-#include "content/browser/tab_contents/tab_contents.h"
#include "content/public/browser/navigation_controller.h"
#include "content/public/browser/navigation_entry.h"
+#include "content/public/browser/web_contents.h"
#include "content/public/browser/web_contents_delegate.h"
#include "googleurl/src/gurl.h"
@@ -30,6 +30,7 @@ using content::NavigationController;
using content::NavigationEntry;
using content::OpenURLParams;
using content::Referrer;
+using content::WebContents;
@interface AnyResultValue : NSObject {
@private
@@ -192,7 +193,7 @@ static NSAppleEventDescriptor* valueToDescriptor(Value* value) {
}
NavigationEntry* entry =
- tabContents_->tab_contents()->GetController().GetActiveEntry();
+ tabContents_->web_contents()->GetController().GetActiveEntry();
if (!entry) {
return nil;
}
@@ -216,12 +217,12 @@ static NSAppleEventDescriptor* valueToDescriptor(Value* value) {
}
NavigationEntry* entry =
- tabContents_->tab_contents()->GetController().GetActiveEntry();
+ tabContents_->web_contents()->GetController().GetActiveEntry();
if (!entry)
return;
const GURL& previousURL = entry->GetVirtualURL();
- tabContents_->tab_contents()->OpenURL(OpenURLParams(
+ tabContents_->web_contents()->OpenURL(OpenURLParams(
url,
content::Referrer(previousURL, WebKit::WebReferrerPolicyDefault),
CURRENT_TAB,
@@ -231,7 +232,7 @@ static NSAppleEventDescriptor* valueToDescriptor(Value* value) {
- (NSString*)title {
NavigationEntry* entry =
- tabContents_->tab_contents()->GetController().GetActiveEntry();
+ tabContents_->web_contents()->GetController().GetActiveEntry();
if (!entry)
return nil;
@@ -244,12 +245,12 @@ static NSAppleEventDescriptor* valueToDescriptor(Value* value) {
}
- (NSNumber*)loading {
- BOOL loadingValue = tabContents_->tab_contents()->IsLoading() ? YES : NO;
+ BOOL loadingValue = tabContents_->web_contents()->IsLoading() ? YES : NO;
return [NSNumber numberWithBool:loadingValue];
}
- (void)handlesUndoScriptCommand:(NSScriptCommand*)command {
- RenderViewHost* view = tabContents_->tab_contents()->GetRenderViewHost();
+ RenderViewHost* view = tabContents_->web_contents()->GetRenderViewHost();
if (!view) {
NOTREACHED();
return;
@@ -259,7 +260,7 @@ static NSAppleEventDescriptor* valueToDescriptor(Value* value) {
}
- (void)handlesRedoScriptCommand:(NSScriptCommand*)command {
- RenderViewHost* view = tabContents_->tab_contents()->GetRenderViewHost();
+ RenderViewHost* view = tabContents_->web_contents()->GetRenderViewHost();
if (!view) {
NOTREACHED();
return;
@@ -269,7 +270,7 @@ static NSAppleEventDescriptor* valueToDescriptor(Value* value) {
}
- (void)handlesCutScriptCommand:(NSScriptCommand*)command {
- RenderViewHost* view = tabContents_->tab_contents()->GetRenderViewHost();
+ RenderViewHost* view = tabContents_->web_contents()->GetRenderViewHost();
if (!view) {
NOTREACHED();
return;
@@ -279,7 +280,7 @@ static NSAppleEventDescriptor* valueToDescriptor(Value* value) {
}
- (void)handlesCopyScriptCommand:(NSScriptCommand*)command {
- RenderViewHost* view = tabContents_->tab_contents()->GetRenderViewHost();
+ RenderViewHost* view = tabContents_->web_contents()->GetRenderViewHost();
if (!view) {
NOTREACHED();
return;
@@ -289,7 +290,7 @@ static NSAppleEventDescriptor* valueToDescriptor(Value* value) {
}
- (void)handlesPasteScriptCommand:(NSScriptCommand*)command {
- RenderViewHost* view = tabContents_->tab_contents()->GetRenderViewHost();
+ RenderViewHost* view = tabContents_->web_contents()->GetRenderViewHost();
if (!view) {
NOTREACHED();
return;
@@ -299,7 +300,7 @@ static NSAppleEventDescriptor* valueToDescriptor(Value* value) {
}
- (void)handlesSelectAllScriptCommand:(NSScriptCommand*)command {
- RenderViewHost* view = tabContents_->tab_contents()->GetRenderViewHost();
+ RenderViewHost* view = tabContents_->web_contents()->GetRenderViewHost();
if (!view) {
NOTREACHED();
return;
@@ -310,27 +311,27 @@ static NSAppleEventDescriptor* valueToDescriptor(Value* value) {
- (void)handlesGoBackScriptCommand:(NSScriptCommand*)command {
NavigationController& navigationController =
- tabContents_->tab_contents()->GetController();
+ tabContents_->web_contents()->GetController();
if (navigationController.CanGoBack())
navigationController.GoBack();
}
- (void)handlesGoForwardScriptCommand:(NSScriptCommand*)command {
NavigationController& navigationController =
- tabContents_->tab_contents()->GetController();
+ tabContents_->web_contents()->GetController();
if (navigationController.CanGoForward())
navigationController.GoForward();
}
- (void)handlesReloadScriptCommand:(NSScriptCommand*)command {
NavigationController& navigationController =
- tabContents_->tab_contents()->GetController();
+ tabContents_->web_contents()->GetController();
const bool checkForRepost = true;
navigationController.Reload(checkForRepost);
}
- (void)handlesStopScriptCommand:(NSScriptCommand*)command {
- RenderViewHost* view = tabContents_->tab_contents()->GetRenderViewHost();
+ RenderViewHost* view = tabContents_->web_contents()->GetRenderViewHost();
if (!view) {
// We tolerate Stop being called even before a view has been created.
// So just log a warning instead of a NOTREACHED().
@@ -355,7 +356,7 @@ static NSAppleEventDescriptor* valueToDescriptor(Value* value) {
// Scripter has not specifed the location at which to save, so we prompt for
// it.
if (!fileURL) {
- tabContents_->tab_contents()->OnSavePage();
+ tabContents_->web_contents()->OnSavePage();
return;
}
@@ -381,21 +382,21 @@ static NSAppleEventDescriptor* valueToDescriptor(Value* value) {
}
}
- tabContents_->tab_contents()->SavePage(mainFile,
+ tabContents_->web_contents()->SavePage(mainFile,
directoryPath,
savePackageType);
}
- (void)handlesCloseScriptCommand:(NSScriptCommand*)command {
- TabContents* contents = tabContents_->tab_contents();
+ WebContents* contents = tabContents_->web_contents();
contents->GetDelegate()->CloseContents(contents);
}
- (void)handlesViewSourceScriptCommand:(NSScriptCommand*)command {
NavigationEntry* entry =
- tabContents_->tab_contents()->GetController().GetLastCommittedEntry();
+ tabContents_->web_contents()->GetController().GetLastCommittedEntry();
if (entry) {
- tabContents_->tab_contents()->OpenURL(OpenURLParams(
+ tabContents_->web_contents()->OpenURL(OpenURLParams(
GURL(chrome::kViewSourceScheme + std::string(":") +
entry->GetURL().spec()),
Referrer(),
@@ -406,7 +407,7 @@ static NSAppleEventDescriptor* valueToDescriptor(Value* value) {
}
- (id)handlesExecuteJavascriptScriptCommand:(NSScriptCommand*)command {
- RenderViewHost* view = tabContents_->tab_contents()->GetRenderViewHost();
+ RenderViewHost* view = tabContents_->web_contents()->GetRenderViewHost();
if (!view) {
NOTREACHED();
return nil;
diff --git a/chrome/browser/ui/cocoa/bookmarks/bookmark_bar_controller.mm b/chrome/browser/ui/cocoa/bookmarks/bookmark_bar_controller.mm
index bacd034..377fff15 100644
--- a/chrome/browser/ui/cocoa/bookmarks/bookmark_bar_controller.mm
+++ b/chrome/browser/ui/cocoa/bookmarks/bookmark_bar_controller.mm
@@ -41,9 +41,9 @@
#import "chrome/browser/ui/cocoa/view_resizer.h"
#include "chrome/common/extensions/extension_constants.h"
#include "chrome/common/pref_names.h"
-#include "content/browser/tab_contents/tab_contents.h"
#include "content/browser/tab_contents/tab_contents_view.h"
#include "content/public/browser/user_metrics.h"
+#include "content/public/browser/web_contents.h"
#include "grit/generated_resources.h"
#include "grit/theme_resources.h"
#include "grit/ui_resources.h"
diff --git a/chrome/browser/ui/cocoa/browser_window_cocoa.mm b/chrome/browser/ui/cocoa/browser_window_cocoa.mm
index 11c9562..64115e5 100644
--- a/chrome/browser/ui/cocoa/browser_window_cocoa.mm
+++ b/chrome/browser/ui/cocoa/browser_window_cocoa.mm
@@ -333,7 +333,7 @@ void BrowserWindowCocoa::UpdateReloadStopState(bool is_loading, bool force) {
void BrowserWindowCocoa::UpdateToolbar(TabContentsWrapper* contents,
bool should_restore_state) {
- [controller_ updateToolbarWithContents:contents->tab_contents()
+ [controller_ updateToolbarWithContents:contents->web_contents()
shouldRestoreState:should_restore_state ? YES : NO];
}
@@ -544,7 +544,7 @@ bool BrowserWindowCocoa::InPresentationMode() {
}
void BrowserWindowCocoa::ShowInstant(TabContentsWrapper* preview) {
- [controller_ showInstant:preview->tab_contents()];
+ [controller_ showInstant:preview->web_contents()];
}
void BrowserWindowCocoa::HideInstant() {
diff --git a/chrome/browser/ui/cocoa/browser_window_controller.h b/chrome/browser/ui/cocoa/browser_window_controller.h
index 7137578..1b86ea6 100644
--- a/chrome/browser/ui/cocoa/browser_window_controller.h
+++ b/chrome/browser/ui/cocoa/browser_window_controller.h
@@ -49,6 +49,10 @@ class TabContents;
@class TabStripView;
@class ToolbarController;
+namespace content {
+class WebContents;
+}
+
@interface BrowserWindowController :
TabWindowController<NSUserInterfaceValidations,
BookmarkBarControllerDelegate,
@@ -210,7 +214,7 @@ class TabContents;
// the specified |tab|. If |shouldRestore| is true, we're switching
// (back?) to this tab and should restore any previous location bar state
// (such as user editing) as well.
-- (void)updateToolbarWithContents:(TabContents*)tab
+- (void)updateToolbarWithContents:(content::WebContents*)tab
shouldRestoreState:(BOOL)shouldRestore;
// Sets whether or not the current page in the frontmost tab is bookmarked.
@@ -311,7 +315,7 @@ class TabContents;
- (NSPoint)bookmarkBubblePoint;
// Shows or hides the Instant preview contents.
-- (void)showInstant:(TabContents*)previewContents;
+- (void)showInstant:(content::WebContents*)previewContents;
- (void)hideInstant;
- (void)commitInstant;
diff --git a/chrome/browser/ui/cocoa/browser_window_controller.mm b/chrome/browser/ui/cocoa/browser_window_controller.mm
index 140fb58..904f255 100644
--- a/chrome/browser/ui/cocoa/browser_window_controller.mm
+++ b/chrome/browser/ui/cocoa/browser_window_controller.mm
@@ -1146,7 +1146,7 @@ enum {
return [tabStripController_ sheetController];
}
-- (void)updateToolbarWithContents:(TabContents*)tab
+- (void)updateToolbarWithContents:(WebContents*)tab
shouldRestoreState:(BOOL)shouldRestore {
[toolbarController_ updateToolbarWithContents:tab
shouldRestoreState:shouldRestore];
@@ -1869,7 +1869,7 @@ willAnimateFromState:(bookmarks::VisualState)oldState
return fullscreenExitBubbleController_.get();
}
-- (void)showInstant:(TabContents*)previewContents {
+- (void)showInstant:(WebContents*)previewContents {
[previewableContentsController_ showPreview:previewContents];
[self updateBookmarkBarVisibilityWithAnimation:NO];
}
diff --git a/chrome/browser/ui/cocoa/browser_window_controller_private.mm b/chrome/browser/ui/cocoa/browser_window_controller_private.mm
index 1bb17f2..f111555 100644
--- a/chrome/browser/ui/cocoa/browser_window_controller_private.mm
+++ b/chrome/browser/ui/cocoa/browser_window_controller_private.mm
@@ -32,8 +32,8 @@
#include "chrome/browser/ui/tab_contents/tab_contents_wrapper.h"
#include "chrome/common/pref_names.h"
#include "content/browser/renderer_host/render_widget_host_view.h"
-#include "content/browser/tab_contents/tab_contents.h"
#include "content/browser/tab_contents/tab_contents_view.h"
+#include "content/public/browser/web_contents.h"
#include "ui/base/ui_base_types.h"
using content::WebContents;
diff --git a/chrome/browser/ui/cocoa/constrained_window_mac.mm b/chrome/browser/ui/cocoa/constrained_window_mac.mm
index ddb038b..e06c6c5 100644
--- a/chrome/browser/ui/cocoa/constrained_window_mac.mm
+++ b/chrome/browser/ui/cocoa/constrained_window_mac.mm
@@ -7,8 +7,8 @@
#import "chrome/browser/ui/cocoa/browser_window_controller.h"
#include "chrome/browser/ui/constrained_window_tab_helper.h"
#include "chrome/browser/ui/tab_contents/tab_contents_wrapper.h"
-#include "content/browser/tab_contents/tab_contents.h"
#include "content/browser/tab_contents/tab_contents_view.h"
+#include "content/public/browser/web_contents.h"
#import "third_party/GTM/AppKit/GTMWindowSheetController.h"
ConstrainedWindowMacDelegateSystemSheet::
@@ -106,7 +106,7 @@ void ConstrainedWindowMac::ShowConstrainedWindow() {
// this case, open the sheet now. Else, Realize() will be called later, when
// our tab becomes visible.
NSWindow* browserWindow =
- wrapper_->tab_contents()->GetView()->GetTopLevelNativeWindow();
+ wrapper_->web_contents()->GetView()->GetTopLevelNativeWindow();
NSWindowController* controller = [browserWindow windowController];
if (controller != nil) {
DCHECK([controller isKindOfClass:[BrowserWindowController class]]);
diff --git a/chrome/browser/ui/cocoa/content_settings/collected_cookies_mac.mm b/chrome/browser/ui/cocoa/content_settings/collected_cookies_mac.mm
index f4d84fe..df43493 100644
--- a/chrome/browser/ui/cocoa/content_settings/collected_cookies_mac.mm
+++ b/chrome/browser/ui/cocoa/content_settings/collected_cookies_mac.mm
@@ -20,7 +20,6 @@
#include "chrome/browser/ui/tab_contents/tab_contents_wrapper.h"
#include "chrome/common/chrome_notification_types.h"
#include "chrome/common/pref_names.h"
-#include "content/browser/tab_contents/tab_contents.h"
#include "content/public/browser/notification_details.h"
#include "content/public/browser/notification_source.h"
#include "grit/generated_resources.h"
diff --git a/chrome/browser/ui/cocoa/dev_tools_controller.mm b/chrome/browser/ui/cocoa/dev_tools_controller.mm
index 7288b01..93db17b 100644
--- a/chrome/browser/ui/cocoa/dev_tools_controller.mm
+++ b/chrome/browser/ui/cocoa/dev_tools_controller.mm
@@ -15,7 +15,7 @@
#include "chrome/browser/ui/tab_contents/tab_contents_wrapper.h"
#import "chrome/browser/ui/cocoa/view_id_util.h"
#include "chrome/common/pref_names.h"
-#include "content/browser/tab_contents/tab_contents.h"
+#include "content/public/browser/web_contents.h"
using content::WebContents;
diff --git a/chrome/browser/ui/cocoa/extensions/browser_actions_controller.mm b/chrome/browser/ui/cocoa/extensions/browser_actions_controller.mm
index 08ea24a..d41b459 100644
--- a/chrome/browser/ui/cocoa/extensions/browser_actions_controller.mm
+++ b/chrome/browser/ui/cocoa/extensions/browser_actions_controller.mm
@@ -25,7 +25,6 @@
#include "chrome/common/chrome_notification_types.h"
#include "chrome/common/extensions/extension_action.h"
#include "chrome/common/pref_names.h"
-#include "content/browser/tab_contents/tab_contents.h"
#include "content/public/browser/notification_observer.h"
#include "content/public/browser/notification_registrar.h"
#include "content/public/browser/notification_details.h"
diff --git a/chrome/browser/ui/cocoa/extensions/extension_action_context_menu.mm b/chrome/browser/ui/cocoa/extensions/extension_action_context_menu.mm
index 8ef4136e..07618585 100644
--- a/chrome/browser/ui/cocoa/extensions/extension_action_context_menu.mm
+++ b/chrome/browser/ui/cocoa/extensions/extension_action_context_menu.mm
@@ -26,10 +26,10 @@
#include "chrome/common/extensions/extension_constants.h"
#include "chrome/common/pref_names.h"
#include "chrome/common/url_constants.h"
-#include "content/browser/tab_contents/tab_contents.h"
#include "content/public/browser/notification_observer.h"
#include "content/public/browser/notification_details.h"
#include "content/public/browser/notification_source.h"
+#include "content/public/browser/web_contents.h"
#include "grit/chromium_strings.h"
#include "grit/generated_resources.h"
#include "ui/base/l10n/l10n_util.h"
diff --git a/chrome/browser/ui/cocoa/find_bar/find_bar_cocoa_controller.mm b/chrome/browser/ui/cocoa/find_bar/find_bar_cocoa_controller.mm
index d1e5405..35e5ff0 100644
--- a/chrome/browser/ui/cocoa/find_bar/find_bar_cocoa_controller.mm
+++ b/chrome/browser/ui/cocoa/find_bar/find_bar_cocoa_controller.mm
@@ -19,8 +19,8 @@
#include "chrome/browser/ui/tab_contents/tab_contents_wrapper.h"
#import "content/browser/find_pasteboard.h"
#include "content/browser/renderer_host/render_view_host.h"
-#include "content/browser/tab_contents/tab_contents.h"
#include "content/browser/tab_contents/tab_contents_view.h"
+#include "content/public/browser/web_contents.h"
#import "third_party/GTM/AppKit/GTMNSAnimation+Duration.h"
const float kFindBarOpenDuration = 0.2;
@@ -234,7 +234,7 @@ const float kRightEdgeOffset = 25;
// cmd-up/down if we ever decide to include |moveToBeginningOfDocument:| in
// the list above.
RenderViewHost* render_view_host =
- contents->tab_contents()->GetRenderViewHost();
+ contents->web_contents()->GetRenderViewHost();
render_view_host->ForwardKeyboardEvent(NativeWebKeyboardEvent(event));
return YES;
}
@@ -299,7 +299,7 @@ const float kRightEdgeOffset = 25;
[focusTracker_ restoreFocusInWindow:[findBarView_ window]])) {
// Fall back to giving focus to the tab contents.
findBarBridge_->
- GetFindBarController()->tab_contents()->tab_contents()->Focus();
+ GetFindBarController()->tab_contents()->web_contents()->Focus();
}
focusTracker_.reset(nil);
}
@@ -468,7 +468,7 @@ const float kRightEdgeOffset = 25;
// Get the size of the container.
gfx::Rect container_rect(
- contents->tab_contents()->GetView()->GetContainerSize());
+ contents->web_contents()->GetView()->GetContainerSize());
// Position the FindBar on the top right corner.
view_rect.set_x(
diff --git a/chrome/browser/ui/cocoa/html_dialog_window_controller.mm b/chrome/browser/ui/cocoa/html_dialog_window_controller.mm
index 62df816..5113ef6 100644
--- a/chrome/browser/ui/cocoa/html_dialog_window_controller.mm
+++ b/chrome/browser/ui/cocoa/html_dialog_window_controller.mm
@@ -294,15 +294,15 @@ void HtmlDialogWindowDelegateBridge::HandleKeyboardEvent(
contentsWrapper_.reset(new TabContentsWrapper(new TabContents(
delegate_->profile(), NULL, MSG_ROUTING_NONE, NULL, NULL)));
[[self window]
- setContentView:contentsWrapper_->tab_contents()->GetNativeView()];
- contentsWrapper_->tab_contents()->SetDelegate(delegate_.get());
+ setContentView:contentsWrapper_->web_contents()->GetNativeView()];
+ contentsWrapper_->web_contents()->SetDelegate(delegate_.get());
// This must be done before loading the page; see the comments in
// HtmlDialogUI.
HtmlDialogUI::GetPropertyAccessor().SetProperty(
- contentsWrapper_->tab_contents()->GetPropertyBag(), delegate_.get());
+ contentsWrapper_->web_contents()->GetPropertyBag(), delegate_.get());
- contentsWrapper_->tab_contents()->GetController().LoadURL(
+ contentsWrapper_->web_contents()->GetController().LoadURL(
delegate_->GetDialogContentURL(),
content::Referrer(),
content::PAGE_TRANSITION_START_PAGE,
diff --git a/chrome/browser/ui/cocoa/hung_renderer_controller.mm b/chrome/browser/ui/cocoa/hung_renderer_controller.mm
index f9eeee9..f445f32 100644
--- a/chrome/browser/ui/cocoa/hung_renderer_controller.mm
+++ b/chrome/browser/ui/cocoa/hung_renderer_controller.mm
@@ -18,8 +18,8 @@
#include "chrome/browser/ui/tab_contents/tab_contents_wrapper.h"
#include "chrome/common/logging_chrome.h"
#include "content/browser/renderer_host/render_view_host.h"
-#include "content/browser/tab_contents/tab_contents.h"
#include "content/public/browser/render_process_host.h"
+#include "content/public/browser/web_contents.h"
#include "content/public/common/result_codes.h"
#include "grit/chromium_strings.h"
#include "grit/generated_resources.h"
@@ -172,9 +172,9 @@ class WebContentsObserverBridge : public content::WebContentsObserver {
scoped_nsobject<NSMutableArray> titles([[NSMutableArray alloc] init]);
scoped_nsobject<NSMutableArray> favicons([[NSMutableArray alloc] init]);
for (TabContentsIterator it; !it.done(); ++it) {
- if (it->tab_contents()->GetRenderProcessHost() ==
+ if (it->web_contents()->GetRenderProcessHost() ==
hungContents_->GetRenderProcessHost()) {
- string16 title = (*it)->tab_contents()->GetTitle();
+ string16 title = (*it)->web_contents()->GetTitle();
if (title.empty())
title = CoreTabHelper::GetDefaultTitle();
[titles addObject:base::SysUTF16ToNSString(title)];
diff --git a/chrome/browser/ui/cocoa/infobars/extension_infobar_controller.mm b/chrome/browser/ui/cocoa/infobars/extension_infobar_controller.mm
index 46ab573..d1f4c3e 100644
--- a/chrome/browser/ui/cocoa/infobars/extension_infobar_controller.mm
+++ b/chrome/browser/ui/cocoa/infobars/extension_infobar_controller.mm
@@ -18,7 +18,7 @@
#include "chrome/common/extensions/extension.h"
#include "chrome/common/extensions/extension_icon_set.h"
#include "chrome/common/extensions/extension_resource.h"
-#include "content/browser/tab_contents/tab_contents.h"
+#include "content/public/browser/web_contents.h"
#include "grit/theme_resources.h"
#include "skia/ext/skia_utils_mac.h"
#include "ui/base/resource/resource_bundle.h"
diff --git a/chrome/browser/ui/cocoa/location_bar/content_setting_decoration.mm b/chrome/browser/ui/cocoa/location_bar/content_setting_decoration.mm
index 2a39581..d0f17a7 100644
--- a/chrome/browser/ui/cocoa/location_bar/content_setting_decoration.mm
+++ b/chrome/browser/ui/cocoa/location_bar/content_setting_decoration.mm
@@ -18,7 +18,7 @@
#include "chrome/browser/ui/content_settings/content_setting_image_model.h"
#include "chrome/browser/ui/tab_contents/tab_contents_wrapper.h"
#include "chrome/common/pref_names.h"
-#include "content/browser/tab_contents/tab_contents.h"
+#include "content/public/browser/web_contents.h"
#include "net/base/net_util.h"
#include "ui/base/l10n/l10n_util.h"
#include "ui/base/resource/resource_bundle.h"
diff --git a/chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.h b/chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.h
index 1f5d9f2..481c33e 100644
--- a/chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.h
+++ b/chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.h
@@ -36,10 +36,6 @@ class SkBitmap;
class StarDecoration;
class ToolbarModel;
-namespace content {
-class WebContents;
-}
-
// A C++ bridge class that represents the location bar UI element to
// the portable code. Wires up an OmniboxViewMac instance to
// the location bar text field, which handles most of the work.
@@ -69,7 +65,7 @@ class LocationBarViewMac : public AutocompleteEditController,
virtual void UpdateContentSettingsIcons() OVERRIDE;
virtual void UpdatePageActions() OVERRIDE;
virtual void InvalidatePageActions() OVERRIDE;
- virtual void SaveStateToContents(TabContents* contents) OVERRIDE;
+ virtual void SaveStateToContents(content::WebContents* contents) OVERRIDE;
virtual void Revert() OVERRIDE;
virtual const OmniboxView* location_entry() const OVERRIDE;
virtual OmniboxView* location_entry() OVERRIDE;
@@ -101,7 +97,7 @@ class LocationBarViewMac : public AutocompleteEditController,
// Updates the location bar. Resets the bar's permanent text and
// security style, and if |should_restore_state| is true, restores
// saved state from the tab (for tab switching).
- void Update(const TabContents* tab, bool should_restore_state);
+ void Update(const content::WebContents* tab, bool should_restore_state);
// Layout the various decorations which live in the field.
void Layout();
diff --git a/chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.mm b/chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.mm
index 6458166..ad3ed60 100644
--- a/chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.mm
+++ b/chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.mm
@@ -47,8 +47,8 @@
#include "chrome/common/extensions/extension_action.h"
#include "chrome/common/extensions/extension_resource.h"
#include "chrome/common/pref_names.h"
-#include "content/browser/tab_contents/tab_contents.h"
#include "content/public/browser/notification_service.h"
+#include "content/public/browser/web_contents.h"
#include "grit/generated_resources.h"
#include "grit/theme_resources.h"
#include "net/base/net_util.h"
@@ -204,12 +204,12 @@ void LocationBarViewMac::InvalidatePageActions() {
}
}
-void LocationBarViewMac::SaveStateToContents(TabContents* contents) {
+void LocationBarViewMac::SaveStateToContents(WebContents* contents) {
// TODO(shess): Why SaveStateToContents vs SaveStateToTab?
omnibox_view_->SaveStateToTab(contents);
}
-void LocationBarViewMac::Update(const TabContents* contents,
+void LocationBarViewMac::Update(const WebContents* contents,
bool should_restore_state) {
bool star_enabled = IsStarEnabled();
command_updater_->UpdateCommandEnabled(IDC_BOOKMARK_PAGE, star_enabled);
diff --git a/chrome/browser/ui/cocoa/location_bar/location_icon_decoration.mm b/chrome/browser/ui/cocoa/location_bar/location_icon_decoration.mm
index 7e14df5..2e08505 100644
--- a/chrome/browser/ui/cocoa/location_bar/location_icon_decoration.mm
+++ b/chrome/browser/ui/cocoa/location_bar/location_icon_decoration.mm
@@ -7,8 +7,8 @@
#include "base/sys_string_conversions.h"
#import "chrome/browser/bookmarks/bookmark_pasteboard_helper_mac.h"
#import "chrome/browser/ui/cocoa/location_bar/location_bar_view_mac.h"
-#include "content/browser/tab_contents/tab_contents.h"
#include "content/public/browser/navigation_entry.h"
+#include "content/public/browser/web_contents.h"
#include "grit/generated_resources.h"
#include "skia/ext/skia_utils_mac.h"
#import "third_party/mozilla/NSPasteboard+Utils.h"
diff --git a/chrome/browser/ui/cocoa/location_bar/page_action_decoration.mm b/chrome/browser/ui/cocoa/location_bar/page_action_decoration.mm
index 4ab83200..39467d9 100644
--- a/chrome/browser/ui/cocoa/location_bar/page_action_decoration.mm
+++ b/chrome/browser/ui/cocoa/location_bar/page_action_decoration.mm
@@ -17,8 +17,8 @@
#include "chrome/common/chrome_notification_types.h"
#include "chrome/common/extensions/extension_action.h"
#include "chrome/common/extensions/extension_resource.h"
-#include "content/browser/tab_contents/tab_contents.h"
#include "content/public/browser/notification_service.h"
+#include "content/public/browser/web_contents.h"
#include "skia/ext/skia_utils_mac.h"
using content::WebContents;
diff --git a/chrome/browser/ui/cocoa/notifications/balloon_controller.mm b/chrome/browser/ui/cocoa/notifications/balloon_controller.mm
index f1a1922..6738f70 100644
--- a/chrome/browser/ui/cocoa/notifications/balloon_controller.mm
+++ b/chrome/browser/ui/cocoa/notifications/balloon_controller.mm
@@ -19,7 +19,7 @@
#import "chrome/browser/ui/cocoa/notifications/balloon_view.h"
#include "chrome/browser/ui/cocoa/notifications/balloon_view_host_mac.h"
#include "content/browser/renderer_host/render_view_host.h"
-#include "content/browser/tab_contents/tab_contents.h"
+#include "content/public/browser/web_contents.h"
#include "grit/generated_resources.h"
#include "grit/theme_resources.h"
#include "ui/base/l10n/l10n_util.h"
diff --git a/chrome/browser/ui/cocoa/omnibox/omnibox_view_mac.h b/chrome/browser/ui/cocoa/omnibox/omnibox_view_mac.h
index aed6ec3..eddcd6d 100644
--- a/chrome/browser/ui/cocoa/omnibox/omnibox_view_mac.h
+++ b/chrome/browser/ui/cocoa/omnibox/omnibox_view_mac.h
@@ -38,36 +38,28 @@ class OmniboxViewMac : public OmniboxView,
// OmniboxView:
virtual AutocompleteEditModel* model() OVERRIDE;
virtual const AutocompleteEditModel* model() const OVERRIDE;
-
- virtual void SaveStateToTab(TabContents* tab) OVERRIDE;
- virtual void Update(const TabContents* tab_for_state_restoring) OVERRIDE;
-
+ virtual void SaveStateToTab(content::WebContents* tab) OVERRIDE;
+ virtual void Update(
+ const content::WebContents* tab_for_state_restoring) OVERRIDE;
virtual void OpenMatch(const AutocompleteMatch& match,
WindowOpenDisposition disposition,
const GURL& alternate_nav_url,
size_t index,
const string16& keyword) OVERRIDE;
-
virtual string16 GetText() const OVERRIDE;
-
virtual bool IsEditingOrEmpty() const OVERRIDE;
virtual int GetIcon() const OVERRIDE;
-
virtual void SetUserText(const string16& text) OVERRIDE;
virtual void SetUserText(const string16& text,
const string16& display_text,
bool update_popup) OVERRIDE;
-
virtual void SetWindowTextAndCaretPos(const string16& text,
size_t caret_pos) OVERRIDE;
-
virtual void SetForcedQuery() OVERRIDE;
-
virtual bool IsSelectAll() OVERRIDE;
virtual bool DeleteAtEndPressed() OVERRIDE;
virtual void GetSelectionBounds(string16::size_type* start,
string16::size_type* end) const OVERRIDE;
-
virtual void SelectAll(bool reversed) OVERRIDE;
virtual void RevertAll() OVERRIDE;
virtual void UpdatePopup() OVERRIDE;
diff --git a/chrome/browser/ui/cocoa/ssl_client_certificate_selector.mm b/chrome/browser/ui/cocoa/ssl_client_certificate_selector.mm
index 7c892ef..e5367be 100644
--- a/chrome/browser/ui/cocoa/ssl_client_certificate_selector.mm
+++ b/chrome/browser/ui/cocoa/ssl_client_certificate_selector.mm
@@ -17,7 +17,6 @@
#import "chrome/browser/ui/cocoa/constrained_window_mac.h"
#include "chrome/browser/ui/tab_contents/tab_contents_wrapper.h"
#include "content/browser/ssl/ssl_client_auth_handler.h"
-#include "content/browser/tab_contents/tab_contents.h"
#include "content/public/browser/browser_thread.h"
#include "grit/generated_resources.h"
#include "net/base/x509_certificate.h"
diff --git a/chrome/browser/ui/cocoa/tab_contents/previewable_contents_controller.h b/chrome/browser/ui/cocoa/tab_contents/previewable_contents_controller.h
index 215d096..396dfaf 100644
--- a/chrome/browser/ui/cocoa/tab_contents/previewable_contents_controller.h
+++ b/chrome/browser/ui/cocoa/tab_contents/previewable_contents_controller.h
@@ -8,7 +8,9 @@
#import <Cocoa/Cocoa.h>
-class TabContents;
+namespace content {
+class WebContents;
+}
// PreviewableContentsController manages the display of up to two tab contents
// views. It is primarily for use with Instant results. This class supports
@@ -27,14 +29,14 @@ class TabContents;
IBOutlet NSView* activeContainer_;
// The preview TabContents. Will be NULL if no preview is currently showing.
- TabContents* previewContents_; // weak
+ content::WebContents* previewContents_; // weak
}
@property(readonly, nonatomic) NSView* activeContainer;
// Sets the current preview and installs its TabContentsView into the view
// hierarchy. Hides the active view. |preview| must not be NULL.
-- (void)showPreview:(TabContents*)preview;
+- (void)showPreview:(content::WebContents*)preview;
// Closes the current preview and shows the active view.
- (void)hidePreview;
diff --git a/chrome/browser/ui/cocoa/tab_contents/previewable_contents_controller.mm b/chrome/browser/ui/cocoa/tab_contents/previewable_contents_controller.mm
index 8e219ce..1358012 100644
--- a/chrome/browser/ui/cocoa/tab_contents/previewable_contents_controller.mm
+++ b/chrome/browser/ui/cocoa/tab_contents/previewable_contents_controller.mm
@@ -6,7 +6,9 @@
#include "base/logging.h"
#include "base/mac/mac_util.h"
-#include "content/browser/tab_contents/tab_contents.h"
+#include "content/public/browser/web_contents.h"
+
+using content::WebContents;
@implementation PreviewableContentsController
@@ -19,7 +21,7 @@
return self;
}
-- (void)showPreview:(TabContents*)preview {
+- (void)showPreview:(WebContents*)preview {
DCHECK(preview);
// Remove any old preview contents before showing the new one.
diff --git a/chrome/browser/ui/cocoa/tab_contents/tab_contents_controller.mm b/chrome/browser/ui/cocoa/tab_contents/tab_contents_controller.mm
index 5a1de8f..abb4401 100644
--- a/chrome/browser/ui/cocoa/tab_contents/tab_contents_controller.mm
+++ b/chrome/browser/ui/cocoa/tab_contents/tab_contents_controller.mm
@@ -7,13 +7,14 @@
#include "base/memory/scoped_nsobject.h"
#include "content/browser/renderer_host/render_view_host.h"
#include "content/browser/renderer_host/render_widget_host_view.h"
-#include "content/browser/tab_contents/tab_contents.h"
+#include "content/browser/tab_contents/render_view_host_manager.h"
#include "content/public/browser/navigation_controller.h"
#include "content/public/browser/notification_observer.h"
#include "content/public/browser/notification_registrar.h"
#include "content/public/browser/notification_details.h"
#include "content/public/browser/notification_source.h"
#include "content/public/browser/notification_types.h"
+#include "content/public/browser/web_contents.h"
using content::NavigationController;
using content::WebContents;
diff --git a/chrome/browser/ui/cocoa/toolbar/toolbar_controller.h b/chrome/browser/ui/cocoa/toolbar/toolbar_controller.h
index 8971264..3995ec7 100644
--- a/chrome/browser/ui/cocoa/toolbar/toolbar_controller.h
+++ b/chrome/browser/ui/cocoa/toolbar/toolbar_controller.h
@@ -27,11 +27,14 @@ class LocationBarViewMac;
@class MenuButton;
class Profile;
@class ReloadButton;
-class TabContents;
@class ToolbarButton;
class ToolbarModel;
@class WrenchMenuController;
+namespace content {
+class WebContents;
+}
+
namespace ToolbarControllerInternal {
class NotificationBridge;
}
@@ -118,7 +121,7 @@ class NotificationBridge;
// the specified |tab|. If |shouldRestore| is true, we're switching
// (back?) to this tab and should restore any previous location bar state
// (such as user editing) as well.
-- (void)updateToolbarWithContents:(TabContents*)tabForRestoring
+- (void)updateToolbarWithContents:(content::WebContents*)tabForRestoring
shouldRestoreState:(BOOL)shouldRestore;
// Sets whether or not the current page in the frontmost tab is bookmarked.
diff --git a/chrome/browser/ui/cocoa/toolbar/toolbar_controller.mm b/chrome/browser/ui/cocoa/toolbar/toolbar_controller.mm
index 08c0c09..523c865 100644
--- a/chrome/browser/ui/cocoa/toolbar/toolbar_controller.mm
+++ b/chrome/browser/ui/cocoa/toolbar/toolbar_controller.mm
@@ -47,10 +47,10 @@
#include "chrome/browser/upgrade_detector.h"
#include "chrome/common/chrome_notification_types.h"
#include "chrome/common/pref_names.h"
-#include "content/browser/tab_contents/tab_contents.h"
#include "content/public/browser/notification_observer.h"
#include "content/public/browser/notification_service.h"
#include "content/public/browser/notification_details.h"
+#include "content/public/browser/web_contents.h"
#include "grit/chromium_strings.h"
#include "grit/generated_resources.h"
#include "grit/theme_resources.h"
@@ -63,6 +63,7 @@
using content::OpenURLParams;
using content::Referrer;
+using content::WebContents;
namespace {
@@ -424,7 +425,7 @@ class NotificationBridge : public content::NotificationObserver {
[homeButton_ setEnabled:commands->IsCommandEnabled(IDC_HOME) ? YES : NO];
}
-- (void)updateToolbarWithContents:(TabContents*)tab
+- (void)updateToolbarWithContents:(WebContents*)tab
shouldRestoreState:(BOOL)shouldRestore {
locationBarView_->Update(tab, shouldRestore ? true : false);
diff --git a/chrome/browser/ui/cocoa/web_intent_picker_cocoa.mm b/chrome/browser/ui/cocoa/web_intent_picker_cocoa.mm
index 98f9619..5f219c0 100644
--- a/chrome/browser/ui/cocoa/web_intent_picker_cocoa.mm
+++ b/chrome/browser/ui/cocoa/web_intent_picker_cocoa.mm
@@ -13,7 +13,6 @@
#import "chrome/browser/ui/cocoa/web_intent_bubble_controller.h"
#include "chrome/browser/ui/intents/web_intent_picker.h"
#include "chrome/browser/ui/intents/web_intent_picker_delegate.h"
-#include "content/browser/tab_contents/tab_contents.h"
#include "skia/ext/skia_utils_mac.h"
// static
diff --git a/chrome/browser/ui/content_settings/content_setting_bubble_model.cc b/chrome/browser/ui/content_settings/content_setting_bubble_model.cc
index d276893..b32cb46 100644
--- a/chrome/browser/ui/content_settings/content_setting_bubble_model.cc
+++ b/chrome/browser/ui/content_settings/content_setting_bubble_model.cc
@@ -22,7 +22,6 @@
#include "chrome/common/pref_names.h"
#include "chrome/common/render_messages.h"
#include "content/browser/renderer_host/render_view_host.h"
-#include "content/browser/tab_contents/tab_contents.h"
#include "content/public/browser/notification_service.h"
#include "content/public/browser/user_metrics.h"
#include "content/public/browser/web_contents.h"
@@ -211,7 +210,7 @@ class ContentSettingSingleRadioGroup
// Initialize the radio group by setting the appropriate labels for the
// content type and setting the default value based on the content setting.
void SetRadioGroup() {
- GURL url = tab_contents()->tab_contents()->GetURL();
+ GURL url = tab_contents()->web_contents()->GetURL();
string16 display_host_utf16;
net::AppendFormattedHost(url,
profile()->GetPrefs()->GetString(prefs::kAcceptLanguages),
@@ -382,7 +381,7 @@ class ContentSettingPluginBubbleModel : public ContentSettingSingleRadioGroup {
virtual void OnCustomLinkClicked() OVERRIDE {
content::RecordAction(UserMetricsAction("ClickToPlay_LoadAll_Bubble"));
DCHECK(tab_contents());
- RenderViewHost* host = tab_contents()->tab_contents()->GetRenderViewHost();
+ RenderViewHost* host = tab_contents()->web_contents()->GetRenderViewHost();
host->Send(new ChromeViewMsg_LoadBlockedPlugins(host->routing_id()));
set_custom_link_enabled(false);
tab_contents()->content_settings()->set_load_plugins_link_enabled(false);
@@ -409,7 +408,7 @@ class ContentSettingPopupBubbleModel : public ContentSettingSingleRadioGroup {
GetBlockedContents(&blocked_contents);
for (std::vector<TabContentsWrapper*>::const_iterator
i = blocked_contents.begin(); i != blocked_contents.end(); ++i) {
- std::string title(UTF16ToUTF8((*i)->tab_contents()->GetTitle()));
+ std::string title(UTF16ToUTF8((*i)->web_contents()->GetTitle()));
// The popup may not have committed a load yet, in which case it won't
// have a URL or title.
if (title.empty())
@@ -486,7 +485,7 @@ class ContentSettingDomainListBubbleModel
return;
// Reset this embedder's entry to default for each of the requesting
// origins currently on the page.
- const GURL& embedder_url = tab_contents()->tab_contents()->GetURL();
+ const GURL& embedder_url = tab_contents()->web_contents()->GetURL();
TabSpecificContentSettings* content_settings =
tab_contents()->content_settings();
const GeolocationSettingsState::StateMap& state_map =
@@ -541,7 +540,7 @@ ContentSettingBubbleModel::ContentSettingBubbleModel(
profile_(profile),
content_type_(content_type) {
registrar_.Add(this, content::NOTIFICATION_WEB_CONTENTS_DESTROYED,
- content::Source<WebContents>(tab_contents->tab_contents()));
+ content::Source<WebContents>(tab_contents->web_contents()));
registrar_.Add(this, chrome::NOTIFICATION_PROFILE_DESTROYED,
content::Source<Profile>(profile_));
}
@@ -576,7 +575,7 @@ void ContentSettingBubbleModel::Observe(
switch (type) {
case content::NOTIFICATION_WEB_CONTENTS_DESTROYED:
DCHECK(source ==
- content::Source<WebContents>(tab_contents_->tab_contents()));
+ content::Source<WebContents>(tab_contents_->web_contents()));
tab_contents_ = NULL;
break;
case chrome::NOTIFICATION_PROFILE_DESTROYED:
diff --git a/chrome/browser/ui/gtk/location_bar_view_gtk.cc b/chrome/browser/ui/gtk/location_bar_view_gtk.cc
index 594a056..8712260 100644
--- a/chrome/browser/ui/gtk/location_bar_view_gtk.cc
+++ b/chrome/browser/ui/gtk/location_bar_view_gtk.cc
@@ -451,7 +451,7 @@ GtkWidget* LocationBarViewGtk::GetPageActionWidget(
return NULL;
}
-void LocationBarViewGtk::Update(const TabContents* contents) {
+void LocationBarViewGtk::Update(const WebContents* contents) {
UpdateStarIcon();
UpdateSiteTypeArea();
UpdateContentSettingsIcons();
@@ -701,7 +701,7 @@ void LocationBarViewGtk::InvalidatePageActions() {
}
}
-void LocationBarViewGtk::SaveStateToContents(TabContents* contents) {
+void LocationBarViewGtk::SaveStateToContents(WebContents* contents) {
location_entry_->SaveStateToTab(contents);
}
diff --git a/chrome/browser/ui/gtk/location_bar_view_gtk.h b/chrome/browser/ui/gtk/location_bar_view_gtk.h
index 9156828..0280e95 100644
--- a/chrome/browser/ui/gtk/location_bar_view_gtk.h
+++ b/chrome/browser/ui/gtk/location_bar_view_gtk.h
@@ -43,7 +43,6 @@ class ContentSettingBubbleGtk;
class ExtensionAction;
class GtkThemeService;
class SkBitmap;
-class TabContents;
class ToolbarModel;
namespace content {
@@ -89,7 +88,7 @@ class LocationBarViewGtk : public AutocompleteEditController,
// Updates the location bar. We also reset the bar's permanent text and
// security style, and, if |tab_for_state_restoring| is non-NULL, also
// restore saved state that the tab holds.
- void Update(const TabContents* tab_for_state_restoring);
+ void Update(const content::WebContents* tab_for_state_restoring);
// Show the bookmark bubble.
void ShowStarBubble(const GURL& url, bool newly_boomkarked);
@@ -125,7 +124,7 @@ class LocationBarViewGtk : public AutocompleteEditController,
virtual void UpdateContentSettingsIcons() OVERRIDE;
virtual void UpdatePageActions() OVERRIDE;
virtual void InvalidatePageActions() OVERRIDE;
- virtual void SaveStateToContents(TabContents* contents) OVERRIDE;
+ virtual void SaveStateToContents(content::WebContents* contents) OVERRIDE;
virtual void Revert() OVERRIDE;
virtual const OmniboxView* location_entry() const OVERRIDE;
virtual OmniboxView* location_entry() OVERRIDE;
diff --git a/chrome/browser/ui/gtk/omnibox/omnibox_view_gtk.cc b/chrome/browser/ui/gtk/omnibox/omnibox_view_gtk.cc
index fb92dc6..b4b5aac 100644
--- a/chrome/browser/ui/gtk/omnibox/omnibox_view_gtk.cc
+++ b/chrome/browser/ui/gtk/omnibox/omnibox_view_gtk.cc
@@ -458,7 +458,7 @@ const AutocompleteEditModel* OmniboxViewGtk::model() const {
return model_.get();
}
-void OmniboxViewGtk::SaveStateToTab(TabContents* tab) {
+void OmniboxViewGtk::SaveStateToTab(WebContents* tab) {
DCHECK(tab);
// If any text has been selected, register it as the PRIMARY selection so it
// can still be pasted via middle-click after the text view is cleared.
@@ -471,7 +471,7 @@ void OmniboxViewGtk::SaveStateToTab(TabContents* tab) {
AutocompleteEditState(model_state, ViewState(GetSelection())));
}
-void OmniboxViewGtk::Update(const TabContents* contents) {
+void OmniboxViewGtk::Update(const WebContents* contents) {
// NOTE: We're getting the URL text here from the ToolbarModel.
bool visibly_changed_permanent_text =
model_->UpdatePermanentText(toolbar_model_->GetText());
diff --git a/chrome/browser/ui/gtk/omnibox/omnibox_view_gtk.h b/chrome/browser/ui/gtk/omnibox/omnibox_view_gtk.h
index 3928488..3c578a7 100644
--- a/chrome/browser/ui/gtk/omnibox/omnibox_view_gtk.h
+++ b/chrome/browser/ui/gtk/omnibox/omnibox_view_gtk.h
@@ -30,7 +30,6 @@ class AutocompleteEditController;
class AutocompleteEditModel;
class AutocompletePopupView;
class Profile;
-class TabContents;
namespace gfx {
class Font;
@@ -91,44 +90,33 @@ class OmniboxViewGtk : public OmniboxView,
// OmniboxView:
virtual AutocompleteEditModel* model() OVERRIDE;
virtual const AutocompleteEditModel* model() const OVERRIDE;
-
- virtual void SaveStateToTab(TabContents* tab) OVERRIDE;
-
- virtual void Update(const TabContents* tab_for_state_restoring) OVERRIDE;
-
+ virtual void SaveStateToTab(content::WebContents* tab) OVERRIDE;
+ virtual void Update(
+ const content::WebContents* tab_for_state_restoring) OVERRIDE;
virtual void OpenMatch(const AutocompleteMatch& match,
WindowOpenDisposition disposition,
const GURL& alternate_nav_url,
size_t index,
const string16& keyword) OVERRIDE;
-
virtual string16 GetText() const OVERRIDE;
-
virtual bool IsEditingOrEmpty() const OVERRIDE;
virtual int GetIcon() const OVERRIDE;
-
virtual void SetUserText(const string16& text) OVERRIDE;
virtual void SetUserText(const string16& text,
const string16& display_text,
bool update_popup) OVERRIDE;
-
virtual void SetWindowTextAndCaretPos(const string16& text,
size_t caret_pos) OVERRIDE;
-
virtual void SetForcedQuery() OVERRIDE;
-
virtual bool IsSelectAll() OVERRIDE;
virtual bool DeleteAtEndPressed() OVERRIDE;
virtual void GetSelectionBounds(string16::size_type* start,
string16::size_type* end) const OVERRIDE;
virtual void SelectAll(bool reversed) OVERRIDE;
virtual void RevertAll() OVERRIDE;
-
virtual void UpdatePopup() OVERRIDE;
virtual void ClosePopup() OVERRIDE;
-
virtual void SetFocus() OVERRIDE;
-
virtual void OnTemporaryTextMaybeChanged(
const string16& display_text,
bool save_original_selection) OVERRIDE;
diff --git a/chrome/browser/ui/views/location_bar/location_bar_view.cc b/chrome/browser/ui/views/location_bar/location_bar_view.cc
index e2a0033..a916884 100644
--- a/chrome/browser/ui/views/location_bar/location_bar_view.cc
+++ b/chrome/browser/ui/views/location_bar/location_bar_view.cc
@@ -300,7 +300,7 @@ void LocationBarView::SetAnimationOffset(int offset) {
animation_offset_ = offset;
}
-void LocationBarView::Update(const TabContents* tab_for_state_restoring) {
+void LocationBarView::Update(const WebContents* tab_for_state_restoring) {
bool star_enabled = star_view_ && !model_->input_in_progress() &&
edit_bookmarks_enabled_.GetValue();
browser_->command_updater()->UpdateCommandEnabled(
@@ -1151,7 +1151,7 @@ void LocationBarView::FocusSearch() {
location_entry_->SetForcedQuery();
}
-void LocationBarView::SaveStateToContents(TabContents* contents) {
+void LocationBarView::SaveStateToContents(WebContents* contents) {
location_entry_->SaveStateToTab(contents);
}
diff --git a/chrome/browser/ui/views/location_bar/location_bar_view.h b/chrome/browser/ui/views/location_bar/location_bar_view.h
index 8d00e17..d7ade8e 100644
--- a/chrome/browser/ui/views/location_bar/location_bar_view.h
+++ b/chrome/browser/ui/views/location_bar/location_bar_view.h
@@ -45,7 +45,6 @@ class LocationIconView;
class PageActionWithBadgeView;
class SelectedKeywordView;
class StarView;
-class TabContents;
class TabContentsWrapper;
class TemplateURLService;
@@ -134,7 +133,7 @@ class LocationBarView : public LocationBar,
// Updates the location bar. We also reset the bar's permanent text and
// security style, and, if |tab_for_state_restoring| is non-NULL, also restore
// saved state that the tab holds.
- void Update(const TabContents* tab_for_state_restoring);
+ void Update(const content::WebContents* tab_for_state_restoring);
Browser* browser() const { return browser_; }
@@ -255,7 +254,7 @@ class LocationBarView : public LocationBar,
virtual void UpdateContentSettingsIcons() OVERRIDE;
virtual void UpdatePageActions() OVERRIDE;
virtual void InvalidatePageActions() OVERRIDE;
- virtual void SaveStateToContents(TabContents* contents) OVERRIDE;
+ virtual void SaveStateToContents(content::WebContents* contents) OVERRIDE;
virtual void Revert() OVERRIDE;
virtual const OmniboxView* location_entry() const OVERRIDE;
virtual OmniboxView* location_entry() OVERRIDE;
diff --git a/chrome/browser/ui/views/omnibox/omnibox_view_views.cc b/chrome/browser/ui/views/omnibox/omnibox_view_views.cc
index 9302fec..b4fe1dc4 100644
--- a/chrome/browser/ui/views/omnibox/omnibox_view_views.cc
+++ b/chrome/browser/ui/views/omnibox/omnibox_view_views.cc
@@ -42,6 +42,8 @@
#include "chrome/browser/ui/views/omnibox/omnibox_view_win.h"
#endif
+using content::WebContents;
+
namespace {
// Textfield for autocomplete that intercepts events that are necessary
@@ -342,7 +344,7 @@ const AutocompleteEditModel* OmniboxViewViews::model() const {
return model_.get();
}
-void OmniboxViewViews::SaveStateToTab(TabContents* tab) {
+void OmniboxViewViews::SaveStateToTab(WebContents* tab) {
DCHECK(tab);
// NOTE: GetStateForTabSwitch may affect GetSelection, so order is important.
@@ -354,7 +356,7 @@ void OmniboxViewViews::SaveStateToTab(TabContents* tab) {
AutocompleteEditState(model_state, ViewState(selection)));
}
-void OmniboxViewViews::Update(const TabContents* contents) {
+void OmniboxViewViews::Update(const WebContents* contents) {
// NOTE: We're getting the URL text here from the ToolbarModel.
bool visibly_changed_permanent_text =
model_->UpdatePermanentText(toolbar_model_->GetText());
diff --git a/chrome/browser/ui/views/omnibox/omnibox_view_views.h b/chrome/browser/ui/views/omnibox/omnibox_view_views.h
index fbc55d0..c524072 100644
--- a/chrome/browser/ui/views/omnibox/omnibox_view_views.h
+++ b/chrome/browser/ui/views/omnibox/omnibox_view_views.h
@@ -97,19 +97,15 @@ class OmniboxViewViews
// OmniboxView:
virtual AutocompleteEditModel* model() OVERRIDE;
virtual const AutocompleteEditModel* model() const OVERRIDE;
-
- virtual void SaveStateToTab(TabContents* tab) OVERRIDE;
-
- virtual void Update(const TabContents* tab_for_state_restoring) OVERRIDE;
-
+ virtual void SaveStateToTab(content::WebContents* tab) OVERRIDE;
+ virtual void Update(
+ const content::WebContents* tab_for_state_restoring) OVERRIDE;
virtual void OpenMatch(const AutocompleteMatch& match,
WindowOpenDisposition disposition,
const GURL& alternate_nav_url,
size_t selected_line,
const string16& keyword) OVERRIDE;
-
virtual string16 GetText() const OVERRIDE;
-
virtual bool IsEditingOrEmpty() const OVERRIDE;
virtual int GetIcon() const OVERRIDE;
virtual void SetUserText(const string16& text) OVERRIDE;
diff --git a/chrome/browser/ui/views/omnibox/omnibox_view_win.cc b/chrome/browser/ui/views/omnibox/omnibox_view_win.cc
index fdcb22a..48e99b3 100644
--- a/chrome/browser/ui/views/omnibox/omnibox_view_win.cc
+++ b/chrome/browser/ui/views/omnibox/omnibox_view_win.cc
@@ -60,6 +60,7 @@
#pragma comment(lib, "riched20.lib") // Needed for the richedit control.
using content::UserMetricsAction;
+using content::WebContents;
///////////////////////////////////////////////////////////////////////////////
// AutocompleteEditModel
@@ -546,7 +547,7 @@ gfx::Font OmniboxViewWin::GetFont() {
return font_;
}
-void OmniboxViewWin::SaveStateToTab(TabContents* tab) {
+void OmniboxViewWin::SaveStateToTab(WebContents* tab) {
DCHECK(tab);
const AutocompleteEditModel::State model_state(
@@ -560,7 +561,7 @@ void OmniboxViewWin::SaveStateToTab(TabContents* tab) {
State(selection, saved_selection_for_focus_change_)));
}
-void OmniboxViewWin::Update(const TabContents* tab_for_state_restoring) {
+void OmniboxViewWin::Update(const WebContents* tab_for_state_restoring) {
const bool visibly_changed_permanent_text =
model_->UpdatePermanentText(toolbar_model_->GetText());
diff --git a/chrome/browser/ui/views/omnibox/omnibox_view_win.h b/chrome/browser/ui/views/omnibox/omnibox_view_win.h
index 55453c1..6d1dfd7 100644
--- a/chrome/browser/ui/views/omnibox/omnibox_view_win.h
+++ b/chrome/browser/ui/views/omnibox/omnibox_view_win.h
@@ -87,44 +87,33 @@ class OmniboxViewWin
virtual const AutocompleteEditModel* model() const OVERRIDE {
return model_.get();
}
-
- virtual void SaveStateToTab(TabContents* tab) OVERRIDE;
-
- virtual void Update(const TabContents* tab_for_state_restoring) OVERRIDE;
-
+ virtual void SaveStateToTab(content::WebContents* tab) OVERRIDE;
+ virtual void Update(
+ const content::WebContents* tab_for_state_restoring) OVERRIDE;
virtual void OpenMatch(const AutocompleteMatch& match,
WindowOpenDisposition disposition,
const GURL& alternate_nav_url,
size_t index,
const string16& keyword) OVERRIDE;
-
virtual string16 GetText() const OVERRIDE;
-
virtual bool IsEditingOrEmpty() const OVERRIDE;
virtual int GetIcon() const OVERRIDE;
-
virtual void SetUserText(const string16& text) OVERRIDE;
virtual void SetUserText(const string16& text,
const string16& display_text,
bool update_popup) OVERRIDE;
-
virtual void SetWindowTextAndCaretPos(const string16& text,
size_t caret_pos) OVERRIDE;
-
virtual void SetForcedQuery() OVERRIDE;
-
virtual bool IsSelectAll() OVERRIDE;
virtual bool DeleteAtEndPressed() OVERRIDE;
virtual void GetSelectionBounds(string16::size_type* start,
string16::size_type* end) const OVERRIDE;
virtual void SelectAll(bool reversed) OVERRIDE;
virtual void RevertAll() OVERRIDE;
-
virtual void UpdatePopup() OVERRIDE;
virtual void ClosePopup() OVERRIDE;
-
virtual void SetFocus() OVERRIDE;
-
virtual void OnTemporaryTextMaybeChanged(
const string16& display_text,
bool save_original_selection) OVERRIDE;
diff --git a/chrome/browser/ui/views/toolbar_view.cc b/chrome/browser/ui/views/toolbar_view.cc
index a26e54a..f3ba99b 100644
--- a/chrome/browser/ui/views/toolbar_view.cc
+++ b/chrome/browser/ui/views/toolbar_view.cc
@@ -51,6 +51,7 @@
#endif
using content::UserMetricsAction;
+using content::WebContents;
// static
const char ToolbarView::kViewClassName[] = "browser/ui/views/ToolbarView";
@@ -219,7 +220,7 @@ void ToolbarView::Init() {
}
}
-void ToolbarView::Update(TabContents* tab, bool should_restore_state) {
+void ToolbarView::Update(WebContents* tab, bool should_restore_state) {
if (location_bar_)
location_bar_->Update(should_restore_state ? tab : NULL);
diff --git a/chrome/browser/ui/views/toolbar_view.h b/chrome/browser/ui/views/toolbar_view.h
index c23ce94..eeec41a 100644
--- a/chrome/browser/ui/views/toolbar_view.h
+++ b/chrome/browser/ui/views/toolbar_view.h
@@ -53,7 +53,7 @@ class ToolbarView : public views::AccessiblePaneView,
// the specified |tab|. If |should_restore_state| is true, we're switching
// (back?) to this tab and should restore any previous location bar state
// (such as user editing) as well.
- void Update(TabContents* tab, bool should_restore_state);
+ void Update(content::WebContents* tab, bool should_restore_state);
// Set focus to the toolbar with complete keyboard access, with the
// focus initially set to the location bar. Focus will be restored
diff --git a/chrome/test/base/test_location_bar.h b/chrome/test/base/test_location_bar.h
index 68a7464..a660273 100644
--- a/chrome/test/base/test_location_bar.h
+++ b/chrome/test/base/test_location_bar.h
@@ -40,7 +40,7 @@ class TestLocationBar : public LocationBar {
virtual void UpdateContentSettingsIcons() OVERRIDE {}
virtual void UpdatePageActions() OVERRIDE {}
virtual void InvalidatePageActions() OVERRIDE {}
- virtual void SaveStateToContents(TabContents* contents) OVERRIDE {}
+ virtual void SaveStateToContents(content::WebContents* contents) OVERRIDE {}
virtual void Revert() OVERRIDE {}
virtual const OmniboxView* location_entry() const OVERRIDE;
virtual OmniboxView* location_entry() OVERRIDE;
diff --git a/chrome/browser/ui/cocoa/omnibox/omnibox_view_mac.mm b/chrome/browser/ui/cocoa/omnibox/omnibox_view_mac.mm
index 6a37d8e..42592291 100644
--- a/chrome/browser/ui/cocoa/omnibox/omnibox_view_mac.mm
+++ b/chrome/browser/ui/cocoa/omnibox/omnibox_view_mac.mm
@@ -6,6 +6,7 @@
#include <Carbon/Carbon.h> // kVK_Return
+#include "base/property_bag.h"
#include "base/string_util.h"
#include "base/sys_string_conversions.h"
#include "base/utf_string_conversions.h"
@@ -16,7 +17,7 @@
#include "chrome/browser/ui/cocoa/event_utils.h"
#include "chrome/browser/ui/cocoa/omnibox/omnibox_popup_view_mac.h"
#include "chrome/browser/ui/toolbar/toolbar_model.h"
-#include "content/browser/tab_contents/tab_contents.h"
+#include "content/public/browser/web_contents.h"
#include "grit/generated_resources.h"
#include "grit/theme_resources.h"
#include "grit/theme_resources_standard.h"
@@ -28,6 +29,8 @@
#include "ui/gfx/mac/nsimage_cache.h"
#include "ui/gfx/rect.h"
+using content::WebContents;
+
// Focus-handling between |field_| and |model_| is a bit subtle.
// Other platforms detect change of focus, which is inconvenient
// without subclassing NSTextField (even with a subclass, the use of a
@@ -100,7 +103,7 @@ struct OmniboxViewMacState {
};
// Returns a lazily initialized property bag accessor for saving our
// state in a TabContents. When constructed |accessor| generates a
// globally-unique id used to index into the per-tab PropertyBag used
// to store the state data.
base::PropertyAccessor<OmniboxViewMacState>* GetStateAccessor() {
@@ -110,11 +113,11 @@ base::PropertyAccessor<OmniboxViewMacState>* GetStateAccessor() {
}
// Accessors for storing and getting the state from the tab.
-void StoreStateToTab(TabContents* tab,
+void StoreStateToTab(WebContents* tab,
const OmniboxViewMacState& state) {
GetStateAccessor()->SetProperty(tab->GetPropertyBag(), state);
}
-const OmniboxViewMacState* GetStateFromTab(const TabContents* tab) {
+const OmniboxViewMacState* GetStateFromTab(const WebContents* tab) {
return GetStateAccessor()->GetProperty(tab->GetPropertyBag());
}
@@ -221,7 +224,7 @@ const AutocompleteEditModel* OmniboxViewMac::model() const {
return model_.get();
}
-void OmniboxViewMac::SaveStateToTab(TabContents* tab) {
+void OmniboxViewMac::SaveStateToTab(WebContents* tab) {
DCHECK(tab);
const bool hasFocus = [field_ currentEditor] ? true : false;
@@ -239,7 +242,7 @@ void OmniboxViewMac::SaveStateToTab(TabContents* tab) {
StoreStateToTab(tab, state);
}
-void OmniboxViewMac::Update(const TabContents* tab_for_state_restoring) {
+void OmniboxViewMac::Update(const WebContents* tab_for_state_restoring) {
// TODO(shess): It seems like if the tab is non-NULL, then this code
// shouldn't need to be called at all. When coded that way, I find
// that the field isn't always updated correctly. Figure out why
@@ -100,7 +103,7 @@ struct OmniboxViewMacState {
};
// Returns a lazily initialized property bag accessor for saving our
-// state in a TabContents. When constructed |accessor| generates a
+// state in a WebContents. When constructed |accessor| generates a
// globally-unique id used to index into the per-tab PropertyBag used
// to store the state data.
diff --git a/chrome/browser/ui/omnibox/location_bar.h b/chrome/browser/ui/omnibox/location_bar.h
index 5a0b908..55e9ec6 100644
--- a/chrome/browser/ui/omnibox/location_bar.h
+++ b/chrome/browser/ui/omnibox/location_bar.h
@@ -23,7 +23,10 @@
class ExtensionAction;
class LocationBarTesting;
class OmniboxView;
-class TabContents;
+
+namespace content {
+class WebContents;
+}
class LocationBar {
public:
@@ -66,9 +69,9 @@ class LocationBar {
// extension is unloaded or crashes.
virtual void InvalidatePageActions() = 0;
// Saves the state of the location bar to the specified TabContents, so that
// it can be restored later. (Done when switching tabs).
- virtual void SaveStateToContents(TabContents* contents) = 0;
+ virtual void SaveStateToContents(content::WebContents* contents) = 0;
// Reverts the location bar. The bar's permanent text will be shown.
virtual void Revert() = 0;
@@ -66,9 +69,9 @@ class LocationBar {
// extension is unloaded or crashes.
virtual void InvalidatePageActions() = 0;
- // Saves the state of the location bar to the specified TabContents, so that
+ // Saves the state of the location bar to the specified WebContents, so that
// it can be restored later. (Done when switching tabs).
diff --git a/chrome/browser/ui/omnibox/omnibox_view.h b/chrome/browser/ui/omnibox/omnibox_view.h
index 5d2f533..a35f00e 100644
--- a/chrome/browser/ui/omnibox/omnibox_view.h
+++ b/chrome/browser/ui/omnibox/omnibox_view.h
@@ -25,7 +25,10 @@
class AutocompleteEditModel;
class CommandUpdater;
class GURL;
-class TabContents;
+
+namespace content {
+class WebContents;
+}
#if defined(TOOLKIT_VIEWS)
@@ -60,12 +63,12 @@ class OmniboxView {
// For use when switching tabs, this saves the current state onto the tab so
// that it can be restored during a later call to Update().
- virtual void SaveStateToTab(TabContents* tab) = 0;
+ virtual void SaveStateToTab(content::WebContents* tab) = 0;
// Called when any LocationBarView state changes. If
// |tab_for_state_restoring| is non-NULL, it points to a TabContents whose
// state we should restore.
- virtual void Update(const TabContents* tab_for_state_restoring) = 0;
+ virtual void Update(const content::WebContents* tab_for_state_restoring) = 0;
// Asks the browser to load the specified match's |destination_url|, which
// is assumed to be one of the popup entries, using the supplied disposition
@@ -60,12 +63,12 @@ class OmniboxView {
// Called when any LocationBarView state changes. If
- // |tab_for_state_restoring| is non-NULL, it points to a TabContents whose
+ // |tab_for_state_restoring| is non-NULL, it points to a WebContents whose
// state we should restore.